+++
title = "Advances in internal model control technique: a review and future prospects"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Complementary Filters]({{< relref "complementary_filters" >}}), [Virtual Sensor Fusion]({{< relref "virtual_sensor_fusion" >}})

Reference
: <sup id="14f767d8ba71d58fa8a3ec876628d750"><a class="reference-link" href="#saxena12_advan_inter_model_contr_techn" title="Sahaj Saxena \&amp; YogeshV Hote, Advances in Internal Model Control Technique: a Review and  Future Prospects, {IETE Technical Review}, v(6), 461 (2012).">(Sahaj Saxena \& YogeshV Hote, 2012)</a></sup>

Author(s)
: Saxena, S., & Hote, Y.

Year
: 2012


## Proposed Filter \\(F(s)\\) {#proposed-filter--fs}

\begin{align\*}
  F(s) &= \frac{1}{(\lambda s + 1)^n} \\\\\\
  F(s) &= \frac{n \lambda + 1}{(\lambda s + 1)^n}
\end{align\*}


## Internal Model Control {#internal-model-control}

Central concept in IMC: control can be acheive only if the control system involves, either implicitly or explicitly, some representation of the process to be controlled.


### Basic IMC structure {#basic-imc-structure}

IMC can be considered as a special case of classical feedback structure with plant \\(G(s)\\) and controller \\(C(s)\\).

The plan model \\(G\_M(s)\\) is added and substracted into the feedback path of feedback controller.

The structure can then be modified and we obtain a new controller \\(Q(s)\\).

IMC is related to the classical controller through:

\begin{align\*}
Q(s) = \frac{C(s)}{1+G\_M(s)C(s)} \\\\\\
C(s) = \frac{Q(s)}{1-G\_M(s)Q(s)}
\end{align\*}

Internal model control system is characterized by a control device consisting of the controller \\(Q(s)\\) and a predictive model \\(G\_M(s)\\) of the process (internal model).
The internal model loop uses the difference between the outputs of the process \\(G(s)\\) to be controlled and the internal model.
This difference \\(E(s)\\) represents the effect of disturbance and mismatch of the model.


### Features of IMC Structure {#features-of-imc-structure}

Three properties:

-   **Dual stability**: assume that, if the plant model is perfect (\\(G\_M(s) = G(s)\\)) and disturbance is absent, the system becomes open-loop and the closed-loop stability is characterized by the stability of \\(G(s)\\) and \\(Q(s)\\)
-   **Perfect control**: assume that, if the controller is equal to the model inverse (\\(Q(s) = G\_M^{-1}\\)) and \\(G(s) = G\_M(s)\\) with \\(G(s)\\) stable, then the system is perfectly controlled.
-   **Zero Offset**: assume that, if the steady state gain of the controller is equal to the inverse of model gain, then offset free control is obtained for constant step of ramp type inputs and disturbances. As expected, the equivalent classical controller leads to integral action.

Issues:

-   the plant model is never perfect
-   inverting the model can cause instability
-   control signal may have large magnitude


## Design procedure for IMC Compensator {#design-procedure-for-imc-compensator}

1.  factorize the plant model as \\(G\_M(s) = G\_{M-}(s)G\_{M+}(s)\\) where \\(G\_{M-}(s)\\) is invertible and minimum phase and \\(G\_{M+}(s)\\) is non-invertible and contains all non-minimum phase elements (delays, RHP zeros). Then, the controller is the inverse of the invertible portion of the plant model: \\(Q\_1(s) = G\_{M-}^{-1}(s)\\).
2.  Filter selection: to make the controller proper and robust against the plant-model mismatch, a low pass filter of the form \\(F(s) = \frac{n \lambda}{(\lambda s + 1)^n}\\) is augmented with the inverted model \\(Q\_1(s)\\): \\(Q(s) = Q\_1(s) F(s)\\). \\(\lambda\\) is a tuning parameter which has an inverse relationship with the speed of closed loop response, \\(n\\) is selected such that \\(Q(s)\\) becomes proper.


## Issues in IMC {#issues-in-imc}


### Filter selection and tuning guidelines {#filter-selection-and-tuning-guidelines}


## Some advantages and future prospects {#some-advantages-and-future-prospects}


## Conclusion {#conclusion}

The interesting feature regarding IMC is that the design scheme is identical to the open-loop control design procedure and the implementation of IMC results in a feedback system, thereby copying the disturbances and parameter uncertainties, while open-loop control is not.

# Bibliography
<a class="bibtex-entry" id="saxena12_advan_inter_model_contr_techn">Saxena, S., & Hote, Y., *Advances in internal model control technique: a review and future prospects*, IETE Technical Review, *29(6)*, 461 (2012).  http://dx.doi.org/10.4103/0256-4602.105001</a> [↩](#14f767d8ba71d58fa8a3ec876628d750)
