+++
title = "Position Sensors"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Inertial Sensors]({{< relref "inertial_sensors" >}}), [Force Sensors]({{< relref "force_sensors" >}}), [Sensor Fusion]({{< relref "sensor_fusion" >}}), [Signal Conditioner]({{< relref "signal_conditioner" >}}), [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}})


## Reviews of Relative Position Sensors {#reviews-of-relative-position-sensors}

-   Fleming, A. J., A review of nanometer resolution position sensors: operation and performance ([Fleming 2013](#orgeaf4a0a)) ([Notes]({{< relref "fleming13_review_nanom_resol_posit_sensor" >}}))

<a id="table--tab:characteristics-relative-sensor"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:characteristics-relative-sensor">Table 1</a></span>:
  Characteristics of relative measurement sensors <a class='org-ref-reference' href="#collette11_review">collette11_review</a>
</div>

| Technology     | Frequency  | Resolution     | Range        | T Range     |
|----------------|------------|----------------|--------------|-------------|
| LVDT           | DC-200 Hz  | 10 nm rms      | 1-10 mm      | -50,100 °C  |
| Eddy current   | 5 kHz      | 0.1-100 nm rms | 0.5-55 mm    | -50,100 °C  |
| Capacitive     | DC-100 kHz | 0.05-50 nm rms | 50 nm - 1 cm | -40,100 °C  |
| Interferometer | 300 kHz    | 0.1 nm rms     | 10 cm        | -250,100 °C |
| Encoder        | DC-1 MHz   | 1 nm rms       | 7-27 mm      | 0,40 °C     |
| Bragg Fibers   | DC-150 Hz  | 0.3 nm rms     | 3.5 cm       | -30,80 °C   |

<a id="table--tab:summary-position-sensors"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:summary-position-sensors">Table 2</a></span>:
  Summary of position sensor characteristics. The dynamic range (DNR) and resolution are approximations based on a full-scale range of \(100 \mu m\) and a first order bandwidth of \(1 kHz\) <a class='org-ref-reference' href="#fleming13_review_nanom_resol_posit_sensor">fleming13_review_nanom_resol_posit_sensor</a>
</div>

| Sensor Type    | Range                          | DNR     | Resolution | Max. BW  | Accuracy  |
|----------------|--------------------------------|---------|------------|----------|-----------|
| Metal foil     | \\(10-500 \mu m\\)             | 230 ppm | 23 nm      | 1-10 kHz | 1% FSR    |
| Piezoresistive | \\(1-500 \mu m\\)              | 5 ppm   | 0.5 nm     | >100 kHz | 1% FSR    |
| Capacitive     | \\(10 \mu m\\) to \\(10 mm\\)  | 24 ppm  | 2.4 nm     | 100 kHz  | 0.1% FSR  |
| Electrothermal | \\(10 \mu m\\) to \\(1 mm\\)   | 100 ppm | 10 nm      | 10 kHz   | 1% FSR    |
| Eddy current   | \\(100 \mu m\\) to \\(80 mm\\) | 10 ppm  | 1 nm       | 40 kHz   | 0.1% FSR  |
| LVDT           | \\(0.5-500 mm\\)               | 10 ppm  | 5 nm       | 1 kHz    | 0.25% FSR |
| Interferometer | Meters                         |         | 0.5 nm     | >100kHz  | 1 ppm FSR |
| Encoder        | Meters                         |         | 6 nm       | >100kHz  | 5 ppm FSR |

Capacitive Sensors and Eddy-Current sensors are compare [here](https://www.lionprecision.com/comparing-capacitive-and-eddy-current-sensors/).


## Capacitive Sensor {#capacitive-sensor}

Description:

-   <http://www.lionprecision.com/tech-library/technotes/cap-0020-sensor-theory.html>
-   <https://www.lionprecision.com/comparing-capacitive-and-eddy-current-sensors>

| Manufacturers  | Links                                                                                            | Country |
|----------------|--------------------------------------------------------------------------------------------------|---------|
| Micro Sense    | [link](http://www.microsense.net/products-position-sensors.htm)                                  | USA     |
| Micro-Epsilon  | [link](https://www.micro-epsilon.com/displacement-position-sensors/capacitive-sensor/)           | Germany |
| PI             | [link](https://www.physikinstrumente.com/en/technology/sensor-technologies/capacitive-sensors/)  | Germany |
| Unipulse       | [link](https://www.unipulse.com/product/ps-ia/)                                                  | Japan   |
| Lion-Precision | [link](https://www.lionprecision.com/products/capacitive-sensors)                                | USA     |
| Fogale         | [link](http://www.fogale.fr/brochures.html)                                                      | USA     |
| Queensgate     | [link](https://www.nanopositioning.com/product-category/nanopositioning/nanopositioning-sensors) | UK      |
| Capacitec      | [link](https://www.capacitec.com/Displacement-Sensing-Systems)                                   | USA     |


## Inductive Sensor (Eddy Current) {#inductive-sensor--eddy-current}

| Manufacturers  | Links                                                                                     |         |
|----------------|-------------------------------------------------------------------------------------------|---------|
| Micro-Epsilon  | [link](https://www.micro-epsilon.com/displacement-position-sensors/eddy-current-sensor/)  | Germany |
| Lion Precision | [link](https://www.lionprecision.com/products/eddy-current-sensors)                       | USA     |
| Cedrat         | [link](https://www.cedrat-technologies.com/en/products/sensors/eddy-current-sensors.html) | France  |
| Kaman          | [link](https://www.kamansensors.com/product/smt-9700/)                                    | USA     |
| Keyence        | [link](https://www.keyence.com/ss/products/measure/measurement%5Flibrary/type/inductive/) | USA     |


## Inductive Sensor (LVDT) {#inductive-sensor--lvdt}

| Manufacturers | Links                                                                                      | Country |
|---------------|--------------------------------------------------------------------------------------------|---------|
| Micro-Epsilon | [link](https://www.micro-epsilon.com/displacement-position-sensors/inductive-sensor-lvdt/) | Germany |
| Keyence       | [link](https://www.keyence.eu/products/measure/contact-distance-lvdt/gt2/index.jsp)        | USA     |


## Interferometers {#interferometers}

| Manufacturers | Links                                                                                                    | Country |
|---------------|----------------------------------------------------------------------------------------------------------|---------|
| Attocube      | [link](http://www.attocube.com/)                                                                         | Germany |
| Zygo          | [link](https://www.zygo.com/?/met/markets/stageposition/zmi/)                                            | USA     |
| Smaract       | [link](https://www.smaract.com/interferometry)                                                           | Germany |
| Qutools       | [link](https://www.qutools.com/qudis/)                                                                   | Germany |
| Renishaw      | [link](https://www.renishaw.com/en/fibre-optic-laser-encoder-products--6594)                             | UK      |
| Sios          | [link](https://sios-de.com/products/length-measurement/laser-interferometer/)                            | Germany |
| Keysight      | [link](https://www.keysight.com/en/pc-1000000393%3Aepsg%3Apgr/laser-heads?nid=-536900395.0&cc=FR&lc=fre) | USA     |

<div class="table-caption">
  <span class="table-number">Table 3</span>:
  Characteristics of Environmental Units
</div>

|           | Temperature (\\(\pm\ ^oC\\)) | Pressure (\\(\pm\ hPa\\)) | Humidity \\(\pm\\% RH\\) | Wavelength Accuracy (\\(\pm\ \text{ppm}\\)) |
|-----------|------------------------------|---------------------------|--------------------------|---------------------------------------------|
| Attocube  | 0.1                          | 1                         | 2                        | 0.5                                         |
| Renishaw  | 0.2                          | 1                         | 6                        | 1                                           |
| Picoscale | 0.2                          | 2                         | 2                        | 1                                           |

([Jang and Kim 2017](#org5a2485c))

<a id="orgdc4dc3c"></a>

{{< figure src="/ox-hugo/position_sensor_interferometer_precision.png" caption="Figure 1: Expected precision of interferometer as a function of measured distance" >}}


## Linear Encoders {#linear-encoders}

| Manufacturers  | Links                                                                 | Country |
|----------------|-----------------------------------------------------------------------|---------|
| Heidenhain     | [link](https://www.heidenhain.com/en%5FUS/products/linear-encoders/)  | Germany |
| MicroE Systems | [link](https://www.celeramotion.com/microe/products/linear-encoders/) | USA     |
| Renishaw       | [link](https://www.renishaw.com/en/browse-encoder-range--6440)        | UK      |


## Bibliography {#bibliography}

<a id="orgeaf4a0a"></a>Fleming, Andrew J. 2013. “A Review of Nanometer Resolution Position Sensors: Operation and Performance.” _Sensors and Actuators a: Physical_ 190 (nil):106–26. <https://doi.org/10.1016/j.sna.2012.10.016>.

<a id="org5a2485c"></a>Jang, Yoon-Soo, and Seung-Woo Kim. 2017. “Compensation of the Refractive Index of Air in Laser Interferometer for Distance Measurement: A Review.” _International Journal of Precision Engineering and Manufacturing_ 18 (12):1881–90. <https://doi.org/10.1007/s12541-017-0217-y>.


## Backlinks {#backlinks}

-   [A review of nanometer resolution position sensors: operation and performance]({{< relref "fleming13_review_nanom_resol_posit_sensor" >}})
-   [Measurement technologies for precision positioning]({{< relref "gao15_measur_techn_precis_posit" >}})
-   [Inertial Sensors]({{< relref "inertial_sensors" >}})
-   [Sensors]({{< relref "sensors" >}})
-   [Collocated Control]({{< relref "collocated_control" >}})
